==> ideaIC-15.0.3-sources.jar: com/intellij/codeInsight/folding/impl/actions/CollapseRegionRecursivelyAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.folding.impl.actions;

import com.intellij.codeInsight.folding.CodeFoldingManager;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Caret;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.FoldRegion;
import com.intellij.openapi.editor.actionSystem.EditorAction;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class CollapseRegionRecursivelyAction extends EditorAction {
  public CollapseRegionRecursivelyAction() {
    super(new BaseFoldingHandler() {
      @Override
      public void doExecute(final Editor editor, @Nullable Caret caret, DataContext dataContext) {
        assert editor.getProject() != null;
        CodeFoldingManager foldingManager = CodeFoldingManager.getInstance(editor.getProject());
        foldingManager.updateFoldRegions(editor);

        final List<FoldRegion> regions = getFoldRegionsForCaret(editor, caret, true);
        editor.getFoldingModel().runBatchFoldingOperation(new Runnable() {
          @Override
          public void run() {
            for (FoldRegion region : regions) {
              region.setExpanded(false);
            }
          }
        });
      }
    });
  }
}

==> ideaIC-171.2014.21-sources.jar: com/intellij/codeInsight/folding/impl/actions/CollapseRegionRecursivelyAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.folding.impl.actions;

import com.intellij.codeInsight.folding.CodeFoldingManager;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Caret;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.FoldRegion;
import com.intellij.openapi.editor.actionSystem.EditorAction;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class CollapseRegionRecursivelyAction extends EditorAction {
  public CollapseRegionRecursivelyAction() {
    super(new BaseFoldingHandler() {
      @Override
      public void doExecute(final Editor editor, @Nullable Caret caret, DataContext dataContext) {
        assert editor.getProject() != null;
        CodeFoldingManager foldingManager = CodeFoldingManager.getInstance(editor.getProject());
        foldingManager.updateFoldRegions(editor);

        final List<FoldRegion> regions = getFoldRegionsForCaret(editor, caret, true);
        editor.getFoldingModel().runBatchFoldingOperation(() -> {
          for (FoldRegion region : regions) {
            region.setExpanded(false);
          }
        });
      }
    });
  }
}
